@@ -28,6 +28,7 @@ use WebGUI::Storage;
 use Test::Deep::NoTest qw(eq_deeply);
 use DateTime::Event::ICal;
 use DateTime::Set;
+use Data::ICal::Entry::Event;
 
 use base 'WebGUI::Asset';
 
@@ -74,6 +75,54 @@ sub addRevision {
     return $newRev;
 }
 
+####################################################################
+
+=head2 add_to_calendar ($iCal)
+
+Build a Data::ICal::Entry::Event object that contains the information for this
+event and add it to the Data::ICal calendar
+
+=head3 $iCal
+
+A Data::ICal object, representing the top-level calendar instance.
+
+=cut
+
+sub add_to_calendar {
+    my $self     = shift;
+    my $session  = $self->session;
+    my $calendar = shift;
+    my $event = Data::ICal::Entry::Event->new();
+    $event->add_properties(
+        'last-modified' => WebGUI::DateTime->new($session, $event->get("revisionDate"))->toIcal,
+        created         => WebGUI::DateTime->new($session, $event->get("creationDate"))->toIcal,
+        sequence        => $self->get('iCalSequenceNumber'),
+        summary         => $self->get('title'),
+        description     => $self->get('description'),
+        location        => $self->get('location'),
+        uid => $self->get('feedUid')
+             ? $self->get('feedUid')
+             : $self->get('assetId') . '@'. $session->config->get("sitename")->[0],
+    );
+    ##WebGUI Specific fields
+    foreach my $prop (qw/groupIdView groupIdEdit url menuTitle timeZone/) {
+        $event->add_property( 'x-webgui-'.lc($prop) => $self->get($prop));
+    }
+    my $eventStart = $self->getIcalStart;
+    my $start_parameters = {};
+    if (! $eventStart =~ /T/) {
+        $start_parameters->{VALUE} = 'DATE';
+    }
+    $event->add_property(dtstart => [ $eventStart, $start_parameters ]);
+    my $eventEnd = $self->getIcalEnd;
+    my $end_parameters = {};
+    if (! $eventEnd =~ /T/) {
+        $end_parameters->{VALUE} = 'DATE';
+    }
+    $event->add_property(dtend => [ $eventEnd, $end_parameters ]);
+    $calendar->add_entry($event);
+}
+
 {
 
 my %dayNamesToICal = (
@@ -371,6 +420,14 @@ sub duplicate {
 	my $newAsset = $self->SUPER::duplicate(@_);
 	my $newStorage = $self->getStorageLocation->copy;
 	$newAsset->update({storageId=>$newStorage->getId});
+    my $links = $self->getRelatedLinks();
+    my $id    = $self->session->id;
+    foreach my $link (@{ $links }) {
+        $link->{new_event}   = 1;
+        $link->{eventlinkId} = $id->generate;
+        $link->{linkurl}     = $link->{linkURL};
+    }
+    $newAsset->setRelatedLinks($links);
 	return $newAsset;
 }
 
@@ -395,12 +452,11 @@ sub generateRecurrence {
     };
     my $db = $self->session->db;
     unless ($db->quickScalar($sql, [$self->get('recurId'), $sdb])) {
-        my $child = $self->get;
-        $child->{startDate} = $sdb;
-        $child->{endDate}   = $edb;
-        $self->getParent->addChild(
-            $child, undef, undef, { skipAutoCommitWorkflows => 1 }
-        );
+        my $child = $self->duplicate({skipAutoCommitWorkflows => 1});
+        $child->update({
+            startDate => $sdb,
+            endDate   => $edb,
+        });
     }
 }
 
@@ -1333,8 +1389,17 @@ sub processPropertiesFromFormPost {
 
     ### Verify the form was filled out correctly...
     my @errors;
-    # If the start date is after the end date
     my $i18n = WebGUI::International->new($session, 'Asset_Event');
+
+    # Verify we got valid dates
+    if ( !eval{ $self->getDateTimeStart; 1 } ) {
+        push @errors, $i18n->get('invalid start date');
+    }
+    if ( !eval{ $self->getDateTimeEnd; 1 } ) {
+        push @errors, $i18n->get('invalid end date');
+    }
+
+    # If the start date is after the end date
     if ($self->get("startDate") gt $self->get("endDate")) {
         push @errors, $i18n->get("The event end date must be after the event start date.");
     }
@@ -1573,14 +1638,18 @@ Extent the method from the super class to delete all storage locations.
 =cut
 
 sub purge {
-    my $self = shift;
-    my $sth = $self->session->db->read("select storageId from Event where assetId=?",[$self->getId]);
-    while (my ($storageId) = $sth->array) {
-        my $storage = WebGUI::Storage->get($self->session,$storageId);
+    my $self    = shift;
+    my $id      = $self->getId;
+    my $session = $self->session;
+    my @storageIds = $session->db->buildArray("select storageId from Event where assetId=?",[$id]);
+    my $success    = $self->SUPER::purge;
+    return 0 unless $success;
+    foreach my $storageId (@storageIds) {
+        my $storage = WebGUI::Storage->get($session, $storageId);
         $storage->delete if defined $storage;
     }
-    $sth->finish;
-    return $self->SUPER::purge;
+    $session->db->write('delete from Event_relatedlink where assetId=?',[$id]);
+    return 1;
 }
 
 #-------------------------------------------------------------------
@@ -2252,20 +2321,24 @@ sub www_edit {
     # End
     $var->{"formRecurEnd"}
         = q|
-        <div><input type="radio" name="recurEndType" id="recurEndType_none" value="none" |.(!$recur->{endDate} && !$recur->{endAfter} ? 'checked="checked"' : '').q|/>
-        <label for="recurEndType_none">|. $i18n->get('No end'). q|</label><br />
+        <div><input type="radio" name="recurEndType" id="recurEndType_none" value="none" |.(!$recur->{endDate} && !$recur->{endAfter} ? 'checked="checked"' : '').q| onclick="toggleRecurEnd()"/>
+        <label for="recurEndType_none">|. $i18n->get('No end'). q|</label>
 
-        <input type="radio" name="recurEndType" id="recurEndType_date" value="date" |.($recur->{endDate} ? 'checked="checked"' : '' ).q| />
-        <label for="recurEndType_date">|. $i18n->get('By date'). q| </label>|
+        <input type="radio" name="recurEndType" id="recurEndType_date" value="date" |.($recur->{endDate} ? 'checked="checked"' : '' ).q| onclick="toggleRecurEnd()"/>
+        <label for="recurEndType_date">|. $i18n->get('By date'). q| </label>
+        <div id="recurEndPattern_date"> |
         . WebGUI::Form::date($session,{ name => "recurEndDate", value => $recur->{endDate}, defaultValue => $recur->{endDate} })
         . q|
         <br />
+        </div>
 
-        <input type="radio" name="recurEndType" id="recurEndType_after" value="after" |.($recur->{endAfter} ? 'checked="checked"' : '' ).q| />
+        <input type="radio" name="recurEndType" id="recurEndType_after" value="after" |.($recur->{endAfter} ? 'checked="checked"' : '' ).q| onclick="toggleRecurEnd()"/>
         <label for="recurEndType_after">|. $i18n->get('After'). q| </label>
+        <div id="recurEndPattern_after">
         <input type="text" size="3" name="recurEndAfter" value="|.$recur->{endAfter}.q|" />
         |. $i18n->get('occurences'). q|.
         </div>
+        </div>
     |;
 
     # Include
@@ -2327,7 +2400,19 @@ sub www_edit {
                 document.getElementById("recurPattern_yearly").style.display = "block";
             }
         }
-        YAHOO.util.Event.onAvailable("recurPattern",function(e) { toggleRecur(); });
+
+        function toggleRecurEnd() {
+            document.getElementById("recurEndPattern_date").style.display = "none";
+            document.getElementById("recurEndPattern_after").style.display = "none";
+
+            if (document.getElementById("recurEndType_date").checked) {
+                document.getElementById("recurEndPattern_date").style.display = "block";
+            }
+            else if (document.getElementById("recurEndType_after").checked) {
+                document.getElementById("recurEndPattern_after").style.display = "block";
+            }
+        }
+        YAHOO.util.Event.onAvailable("recurPattern",function(e) { toggleRecur(); toggleRecurEnd(); });
         </script>
 ENDJS
 
