@@ -92,6 +92,24 @@ sub setPrivileges {
     );
 }
 
+#----------------------------------------------------------------------------
+
+=head2 commit ( )
+
+Override commit to remove all privileges for previous revisions' storage 
+locations
+
+=cut
+
+sub commit {
+    my ( $self, @args ) = @_;
+
+    for my $rev ( grep { $_->get("revisionDate") < $self->get("revisionDate") } @{$self->getRevisions} ) {
+        $rev->getStorageLocation->trash;
+    }
+
+    return $self->SUPER::commit( @args );
+}
 
 #-------------------------------------------------------------------
 
@@ -430,7 +448,6 @@ sub processPropertiesFromFormPost {
     return undef;
 }
 
-
 #-------------------------------------------------------------------
 
 =head2 purge 
@@ -479,6 +496,20 @@ sub purgeRevision {
 
 #----------------------------------------------------------------------------
 
+=head2 restore ( )
+
+Override trash restore to restore storage location
+
+=cut
+
+sub restore {
+    my ( $self, @args ) = @_;
+    $self->setPrivileges;
+    return $self->SUPER::restore( @args );
+}
+
+#----------------------------------------------------------------------------
+
 =head2 setFile ( [pathtofile] )
 
 Tells the asset to do all the postprocessing on the file (setting privs, thubnails, or whatever).
@@ -561,6 +592,23 @@ sub setStorageLocation {
     }
 }
 
+#----------------------------------------------------------------------------
+
+=head2 trash ( )
+
+Override to put the attached file in the trash too
+
+=cut
+
+sub trash {
+    my ( $self, @args ) = @_;
+    my $return = $self->SUPER::trash( @args );
+
+    $self->getStorageLocation->trash;
+
+    return $return;
+}
+
 #-------------------------------------------------------------------
 
 =head2 update
@@ -580,7 +628,7 @@ sub update {
 	$self->SUPER::update(@_);
 	##update may have entered a new storageId.  Reset the cached one just in case.
 	if ($self->get("storageId") ne $before{storageId}) {
-		$self->setStorageLocation;
+		delete $self->{_storageLocation};
 	}
 	if ($self->get("ownerUserId") ne $before{owner} || $self->get("groupIdEdit") ne $before{edit} || $self->get("groupIdView") ne $before{view}) {
         $self->setPrivileges;
