@@ -38,6 +38,9 @@ sub _drawQueryBuilder {
 			"!=" => $i18n->get("isnt")
 		};
 	}
+	$operator{checkList} = {
+		"+~" => $i18n->get("contains"),
+	};
 	$operator{integer} = {
 		"=" => $i18n->get("equal to"),
 		"!=" => $i18n->get("not equal to"),
@@ -93,6 +96,8 @@ sub _drawQueryBuilder {
 		# The value select field
 		my $valFieldName = "val_field".$i;
         my $options = $fields->{$field}{possibleValues};
+        ##Only allow one at a time to be selected, and work with current JS for choosing which one.
+        $fieldType = 'radioList' if $fieldType eq 'checkList';
 		my $valueField = WebGUI::Form::dynamicField($session,
 			fieldType=>$fieldType,
 			name=>$valFieldName,
@@ -105,8 +110,9 @@ sub _drawQueryBuilder {
 
 		# Table row with field info
         my $disabled = $self->{_disabled};
+        my $odd_row = $i % 2 ? q{class="qbtr_alt"} : "";
 		$output .= qq|
-		<tr>
+		<tr $odd_row>
 		<td class="qbtdleft"><p class="qbfieldLabel">$fieldLabel</p></td>
 		<td class="qbtd">
 		$opField
@@ -272,7 +278,7 @@ sub getContentLastModified {
     my $shortcut = $self->getShortcut;
     my $shortcuttedRev;
     if (defined $shortcut) {
-        $shortcuttedRev = $shortcut->get('revisionDate');
+        $shortcuttedRev = $shortcut->getContentLastModified;
         return $assetRev > $shortcuttedRev ? $assetRev : $shortcuttedRev;
     } else {
         return 0;
@@ -379,7 +385,6 @@ sub getFieldsList {
 	foreach my $field (@{WebGUI::ProfileField->getFields($session)}) {
 		my $fieldId = $field->getId;
 		next if $fieldId =~ /contentPositions/;
-        $session->log->warn($fieldId);
 		$fieldNames{$fieldId} = $field->getLabel.' ['.$fieldId.']';
 	}
 	$output .= '<table cellspacing="0" cellpadding="3" border="1"><tr><td><table cellspacing="0" cellpadding="3" border="0">';
@@ -393,8 +398,6 @@ sub getFieldsList {
 		-vertical=>1,
 		-uiLevel=>9
 	);
-    $session->log->warn($list->get('uiLevel'));
-    $session->log->warn($list->passUiLevelCheck);
 	$output .= $list->toHtmlWithWrapper;
 	$output .= '</table></td><td><table cellspacing="0" cellpadding="3" border="0">';
 	my @prefFieldsToImport = $self->getPrefFieldsToImport;
@@ -603,8 +606,8 @@ sub getShortcutByCriteria {
 	# |              |             |
 	# |- $field      |_ $operator  |- $value
 	# |_ $attribute                |_ $attribute
-	my $operator = qr/<>|!=|=|>=|<=|>|<|like/i;
-	my $attribute = qr/['"][^()|=><!]+['"]|[^()|=><!\s]+/i; 
+    my $operator = qr/<>|!=|=|>=|<=|>|<|like|\+~/i;
+    my $attribute = qr/['"][^()|=><!]+['"]|[^()|=><!\s]+/i; 
                                                                                                       
 	my $constraint = $criteria;
 	
@@ -612,6 +615,7 @@ sub getShortcutByCriteria {
 	my $db = $self->session->db;
 	my $counter = "b";
 	my @joins = ();
+    ##Transform the expression into valid SQL
 	foreach my $expression ($criteria =~ /($attribute\s*$operator\s*$attribute)/gi) {
 		# $expression will match "State = Wisconsin"
 
@@ -619,9 +623,10 @@ sub getShortcutByCriteria {
 						# We need it later.
 		push(@joins," left join metaData_values ".$counter."_v on a.assetId=".$counter."_v.assetId ");
 		# Get the field (State) and the value (Wisconsin) from the $expression.
-	        $expression =~ /($attribute)\s*$operator\s*($attribute)/gi;
+	        $expression =~ /($attribute)\s*($operator)\s*($attribute)/gi;
 	        my $field = $1;
-	        my $value = $2;
+            my $current_operator = $2;
+	        my $value = $3;
 
 		# quote the field / value variables.
 		my $quotedField = $field;
@@ -629,18 +634,21 @@ sub getShortcutByCriteria {
 		unless ($field =~ /^\s*['"].*['"]\s*/) {
 			$quotedField = $db->quote($field);
 		}
-                unless ($value =~ /^\s*['"].*['"]\s*/) {
-                        $quotedValue = $db->quote($value);
-                }
+        unless ($value =~ /^\s*['"].*['"]\s*/) {
+            $quotedValue = $db->quote($value);
+        }
 		
 		# transform replacement from "State = Wisconsin" to 
 		# "(fieldname=State and value = Wisconsin)"
 		my $clause = "(".$counter."_p.fieldName=".$quotedField." and ".$counter."_v.value ";
-	        $replacement =~ s/\Q$field/$clause/;
-	        $replacement =~ s/\Q$value/$quotedValue )/i;
+        $replacement =~ s/\Q$field/$clause/;
+        $replacement =~ s/\Q$value/$quotedValue )/i;
 
 		# replace $expression with the new $replacement in $constraint.
-	        $constraint =~ s/\Q$expression/$replacement/;
+        $constraint =~ s/\Q$expression/$replacement/;
+        if ($current_operator eq '+~') {
+            $constraint =~ s/and ${counter}_v\.value\s*\+~\s*$quotedValue/and FIND_IN_SET($quotedValue, REPLACE(${counter}_v.value,"\\n",","))/;
+        }
 		push (@joins, " left join metaData_properties ".$counter."_p on ".$counter."_p.fieldId=".$counter."_v.fieldId ");
 		$counter++;
 	}
@@ -789,6 +797,19 @@ sub notLinked {
 
 #-------------------------------------------------------------------
 
+=head2 paste ( )
+
+Pasting assets under a Shortcut can cause lots of problems, including infinite loops
+for operations like paste, and purge.
+
+=cut
+
+sub paste {
+    return 0;
+}
+
+#-------------------------------------------------------------------
+
 =head2 prepareView ( )
 
 See WebGUI::Asset::prepareView() for details.  Extends the base class to call prepareView
