@@ -21,6 +21,7 @@ use WebGUI::Asset::Template::HTMLTemplate;
 use WebGUI::Utility;
 use WebGUI::Form;
 use WebGUI::Exception;
+use List::MoreUtils qw{ any };
 use Tie::IxHash;
 use Clone qw/clone/;
 use HTML::Packer;
@@ -47,6 +48,52 @@ These methods are available from this class:
 
 #-------------------------------------------------------------------
 
+=head2 addAttachments ( new_attachments )
+
+Adds attachments to this template.  New attachments are added to the end of the current set of
+attachments.
+
+=head3 new_attachments
+
+An arrayref of hashrefs, where each hashref should have at least url and type.  All
+other keys will be ignored.
+
+=cut
+
+sub addAttachments {
+    my ($self, $new_attachments) = @_;
+    my $attachments = $self->getAttachments();
+
+    foreach my $a (@{ $new_attachments }) {
+        push @{ $attachments }, {
+            url  => $a->{url},
+            type => $a->{type},
+        };
+    }
+    my $json = JSON->new->encode( $attachments );
+    $self->update({ attachmentsJson => $json, });
+}
+
+#-------------------------------------------------------------------
+
+=head2 cut ( )
+
+Extend the base method to handle cutting the User Function Style template and destroying your site.
+If the current template is the User Function Style template with the Fail Safe template.
+
+=cut
+
+sub cut {
+    my ( $self )    = @_;
+    my $returnValue = $self->SUPER::cut();
+    if ($returnValue && $self->getId eq $self->session->setting->get('userFunctionStyleId')) {
+        $self->session->setting->set('userFunctionStyleId', 'PBtmpl0000000000000060');
+    }
+    return $returnValue;
+}
+
+#-------------------------------------------------------------------
+
 =head2 definition ( session, definition )
 
 Defines the properties of this asset.
@@ -109,6 +156,12 @@ sub definition {
                 fieldType       => 'yesNo',
                 defaultValue    => 0,
             },
+            storageIdExample => {
+                fieldType       => 'image',
+            },
+            attachmentsJson => {
+                fieldType       => 'JsonTable',
+            },
         },
     };
     return $class->SUPER::definition($session,$definition);
@@ -116,33 +169,6 @@ sub definition {
 
 #-------------------------------------------------------------------
 
-=head2 addAttachments ( attachments )
-
-Adds attachments to this template.  Attachments is an arrayref of hashrefs,
-where each hashref should have at least url, type, and sequence as keys.
-
-=cut
-
-sub addAttachments {
-    my ($self, $attachments) = @_;
-
-    my $db = $self->session->db;
-
-    foreach my $a (@$attachments) {
-        my %params = (
-            templateId   => $self->getId, 
-            revisionDate => $self->get('revisionDate'),
-            url          => $a->{url},
-            type         => $a->{type},
-            sequence     => $a->{sequence},
-            attachId     => 'new',
-        );
-        $db->setRow('template_attachments', 'attachId', \%params);
-    }
-}
-
-#-------------------------------------------------------------------
-
 =head2 addRevision ( )
 
 Override the master addRevision to copy attachments
@@ -153,7 +179,6 @@ sub addRevision {
     my ( $self, $properties, @args ) = @_;
     my $asset = $self->SUPER::addRevision($properties, @args);
     delete $properties->{templatePacked};
-    $asset->addAttachments($self->getAttachments);
     return $asset;
 }
 
@@ -189,7 +214,10 @@ sub duplicate {
 	my $self = shift;
 	my $newTemplate = $self->SUPER::duplicate;
     $newTemplate->update({isDefault => 0});
-    $newTemplate->addAttachments($self->getAttachments);
+    if ( my $storageId = $self->get('storageIdExample') ) {
+        my $newStorage  = WebGUI::Storage->get( $self->session, $storageId )->copy;
+        $newTemplate->update({ storageIdExample => $newStorage->getId });
+    }
     return $newTemplate;
 }
 
@@ -204,7 +232,9 @@ Override to add attachments to package data
 sub exportAssetData {
     my ( $self ) = @_;
     my $data    = $self->SUPER::exportAssetData;
-    $data->{template_attachments} = $self->getAttachments;
+    if ( $self->get('storageIdExample') ) {
+        push @{$data->{storage}}, $self->get('storageIdExample');
+    }
     return $data;
 }
 
@@ -224,27 +254,24 @@ If defined, will limit the attachments to this type; e.g., passing
 
 sub getAttachments {
 	my ( $self, $type ) = @_;
-	my @params = ($self->getId, $self->get('revisionDate'));
-	my $typeString;
 
-	if ($type) {
-		$typeString = 'AND type = ?';
-		push(@params, $type);
-	}
+    return [] if !$self->get('attachmentsJson');
 
-	my $sql = qq{
-		SELECT 
-			* 
-		FROM 
-			template_attachments 
-		WHERE 
-			templateId = ?
-            AND revisionDate = ?
-			$typeString
-		ORDER BY
-			type, sequence ASC
-	};
-	return $self->session->db->buildArrayRefOfHashRefs($sql, \@params);
+    my $attachments = JSON->new->decode( $self->get('attachmentsJson') );
+
+    # We want it all and we want it now
+    if ( !$type ) {
+        return $attachments;
+    }
+
+    my $output  = [];
+    for my $attach ( @{$attachments} ) {
+        if ( $attach->{type} eq $type ) {
+            push @{$output}, $attach;
+        }
+    }
+
+    return $output;
 }
 
 #-------------------------------------------------------------------
@@ -319,77 +346,56 @@ sub getEditForm {
 			);
 	}
 
-    ### Template attachments
-	my $session = $self->session;
-	my @headers = map { '<th>' . $i18n->get("attachment header $_") . '</th>' } 
-                      qw(index type url remove);
-
-    tie my %attachmentTypeNames, 'Tie::IxHash' => (
-        stylesheet => $i18n->get('css label'),
-        headScript => $i18n->get('js head label'),
-        bodyScript => $i18n->get('js body label'),
+    $tabform->getTab('properties')->jsonTable(
+        name        => 'attachmentsJson', 
+        value       => $self->get('attachmentsJson'),
+        label       => $i18n->get("attachment display label"),
+        fields      => [
+            {
+                type            => "text",
+                name            => "url",
+                label           => $i18n->get('attachment header url'),
+                size            => '48',
+            },
+            {
+                type            => "select",
+                name            => "type",
+                label           => $i18n->get('attachment header type'),
+                options         => [
+                    stylesheet => $i18n->get('css label'),
+                    headScript => $i18n->get('js head label'),
+                    bodyScript => $i18n->get('js body label'),
+                ],
+            },
+        ],
     );
 
-	my $table = '<table id="attachmentDisplay">';
-	$table .= "<thead><tr>@headers</tr></thead><tbody id='addAnchor'>";
-	foreach my $a ( @{ $self->getAttachments } ) {
-		my ($seq, $type, $url) = @{$a}{qw(sequence type url)};
-        # escape macros in the url so they don't get processed
-        $url =~ s/\^/&#94;/g;
-		my $del = WebGUI::Form::checkbox(
-			$session, { 
-				name   => 'removeAttachment',
-				value  => $url,
-				extras => 'class="id"',
-            }
+        $tabform->getTab('properties')->image( 
+            name        => 'storageIdExample',
+            value       => $self->getValue('storageIdExample'),
+            label       => $i18n->get('field storageIdExample'),
+            hoverHelp   => $i18n->get('field storageIdExample description'),
         );
-		my @data = (
-			"<td class='index'>$seq</td>", 
-			"<td class='type'>$type</td>", 
-			"<td class='url'>$url</td>", 
-			"<td>$del</td>",
-		);
-		$table .= "<tr class='existingAttachment'>@data</tr>";
-	}
-	$table .= '</tbody></table>';
-	my $properties = $tabform->getTab('properties');
-	my $label = $i18n->get('attachment display label');
-	$properties->raw("<tr><td>$label</td><td>$table</td></tr>");
-
-	my @data = map { "<td>$_</td>" } (
-		WebGUI::Form::integer(
-			$session, { size => '2', id => 'addBoxIndex' }
-		),
-		WebGUI::Form::selectBox(
-			$session, { options => \%attachmentTypeNames, id => 'addBoxType' }
-		),
-		WebGUI::Form::text($session, { id => 'addBoxUrl', size => 40 }),
-		WebGUI::Form::button(
-			$session, { 
-				value  => $i18n->get('attachment add button'), 
-				extras => 'onclick="addClick()"' 
-			}
-		),
-	);
-
-	my ($style, $url) = $self->session->quick(qw(style url));
-	$style->setScript($url->extras('yui/build/yahoo/yahoo-min.js'),           {type => 'text/javascript'});
-	$style->setScript($url->extras('yui/build/json/json-min.js'),             {type => 'text/javascript'});
-	$style->setScript($url->extras('yui/build/dom/dom-min.js'),               {type => 'text/javascript'});
-	$style->setScript($url->extras('yui/build/event/event-min.js'),           {type => 'text/javascript'});
-	$style->setScript($url->extras('yui/build/connection/connection-min.js'), {type => 'text/javascript'});
-	$style->setScript($url->extras('yui-webgui/build/i18n/i18n.js'),          {type => 'text/javascript'});
-
-	pop(@headers);
-	my $scriptUrl = $url->extras('templateAttachments.js');
-	$table = "<table id='addBox'><tr>@headers</tr><tr>@data</tr></table>";
-	$table .= qq(<script type="text/javascript" src="$scriptUrl"></script>);
-	$label = $i18n->get('attachment add field label');
-	$properties->raw("<tr><td>$label</td><td>$table</td></tr>");
 
 	return $tabform;
 }
 
+#-------------------------------------------------------------------
+
+=head2 getExampleImageUrl ( )
+
+Get the URL to the example image of this template, if any
+
+=cut
+
+sub getExampleImageUrl {
+    my ( $self ) = @_;
+    if ( my $storageId = $self->get('storageIdExample') ) {
+        my $storage = WebGUI::Storage->get( $self->session, $storageId );
+        return $storage->getUrl( $storage->getFiles->[0] );
+    }
+    return;
+}
 
 #-------------------------------------------------------------------
 
@@ -457,28 +463,38 @@ A parser class to use. Defaults to "WebGUI::Asset::Template::HTMLTemplate"
 sub getParser {
     my $class = shift;
     my $session = shift;
-    my $parser = shift || $session->config->get("defaultTemplateParser") || "WebGUI::Asset::Template::HTMLTemplate";
+    my $parser = shift;
 
-    if ($parser eq "") {
-        return WebGUI::Asset::Template::HTMLTemplate->new($session);
-    } else {
-        eval("use $parser");
-        return $parser->new($session);
+    # If parser is not in the config, throw an error message
+    if ( $parser && $parser ne $session->config->get('defaultTemplateParser') 
+                && !any { $_ eq $parser } @{$session->config->get('templateParsers')} ) {
+        WebGUI::Error::NotInConfig->throw(
+            error       => "Attempted to load template parser '$parser' that is not in config file",
+            module      => $parser,
+            configKey   => 'templateParsers',
+        );
     }
+    else {
+        $parser ||= $session->config->get("defaultTemplateParser") || "WebGUI::Asset::Template::HTMLTemplate";
+    }
+
+    WebGUI::Pluggable::load( $parser );
+    return $parser->new($session);
 }
 
 #-------------------------------------------------------------------
 
 =head2 importAssetCollateralData ( data )
 
-Override to import attachments
+Override to import attachments from old versions of WebGUI
 
 =cut
 
 sub importAssetCollateralData {
     my ( $self, $data, @args ) = @_;
-    $self->removeAttachments;
-    $self->addAttachments( $data->{template_attachments} );
+    if ( $data->{template_attachments} ) {
+        $self->update( { attachmentsJson => JSON::to_json($data->{template_attachments}) } );
+    }
     return $self->SUPER::importAssetCollateralData( $data, @args );
 }
     
@@ -509,7 +525,6 @@ sub packTemplate {
     my ( $self, $template ) = @_;
     my $packed  = $template;
     HTML::Packer::minify( \$packed, {
-        remove_comments     => 1,
         do_javascript       => "shrink",
         do_stylesheet       => "minify",
     } );
@@ -635,6 +650,7 @@ Extends the master class to handle template parsers, namespaces and template att
 
 sub processPropertiesFromFormPost {
 	my $self = shift;
+        my $session = $self->session;
 	$self->SUPER::processPropertiesFromFormPost;
     # TODO: Perhaps add a way to check template syntax before it blows stuff up?
     my %data;
@@ -657,28 +673,7 @@ sub processPropertiesFromFormPost {
     }
 
     ### Template attachments
-    my $f    = $self->session->form;
-    my $p    = $f->paramsHashRef;
-    my @nums = grep {$_} map { my ($i) = /^attachmentUrl(\d+)$/; $i } keys %$p;
-    my @add;
-    
-    # Remove all attachments first, then re-add whatever's left in the form
-    $self->removeAttachments;
-
-    foreach my $n (@nums) {
-        my ($index, $type, $url) = 
-            map { $f->process('attachment' . $_ . $n) }
-            qw(Index Type Url);
-
-        push(
-            @add, {
-                sequence     => $index,
-                url          => $url,
-                type         => $type,
-            }
-        );
-    }
-    $self->addAttachments(\@add);
+    $self->update({ attachmentsJson => $session->form->process( 'attachmentsJson', 'JsonTable' ), });
 
     return;
 }
@@ -720,35 +715,29 @@ sub processRaw {
 
 =head2 purge ( )
 
-Extend the master to purge attachments in all revisions.
+Extend the base method to handle purging the User Function Style template and destroying your site.
+If the current template is the User Function Style template with the Fail Safe template.
 
 =cut
 
 sub purge {
-    my $self = shift;
-    $self->session->db->write('delete from template_attachments where templateId=?', [$self->getId]);
-    return $self->SUPER::purge(@_);
-}
-
-#-------------------------------------------------------------------
-
-=head2 purgeRevision ( )
-
-Extend the master purgeRevision to purge attachments
-
-=cut
-
-sub purgeRevision {
-    my $self = shift;
-    $self->removeAttachments;
-    return $self->SUPER::purgeRevision(@_);
+	my $self = shift;
+    my $returnValue = $self->SUPER::purge;
+    if ($returnValue && $self->getId eq $self->session->setting->get('userFunctionStyleId')) {
+        $self->session->setting->set('userFunctionStyleId', 'PBtmpl0000000000000060');
+    }
+	return $returnValue;
 }
 
 #-------------------------------------------------------------------
 
 =head2 removeAttachments ( urls )
 
-Removes attachments. C<urls> is an arrayref of URLs to remove. If C<urls>
+Removes attachments. 
+
+=head3 urls
+
+C<urls> is an arrayref of URLs to remove. If C<urls>
 is not defined, will remove all attachments for this revision.
 
 =cut
@@ -756,28 +745,14 @@ is not defined, will remove all attachments for this revision.
 sub removeAttachments {
     my ($self, $urls) = @_;
 
-    my $db    = $self->session->db;
-    my $dbh   = $db->dbh;
-    my $rmsql = qq{
-        DELETE FROM 
-            template_attachments
-        WHERE
-            templateId = ?
-            AND revisionDate = ?
-    };
-    
-    if ( $urls && @{$urls} ) {
-        my $in    = join(',', map { $dbh->quote($_) } @{$urls});
-        $rmsql .= qq{
-            AND url IN ($in)
-        };
+    my @attachments = ();
+
+    if ($urls) {
+        @attachments = grep { !isIn($_->{url}, @{ $urls }) } @{ $self->getAttachments() };
     }
 
-    my @params = (
-        $self->getId,
-        $self->get('revisionDate'),
-    );
-    $db->write($rmsql, \@params);
+    my $json = JSON->new->encode( \@attachments );
+    $self->update({ attachmentsJson => $json, });
 }
 
 #-------------------------------------------------------------------
@@ -851,7 +826,7 @@ ENDHTML
                 . $i18n->get( "warning default template" )
                 . q{</p><p>}
                 . sprintf( q{<a href="} . $duplicateUrl . q{">%s</a>}, $i18n->get( "make duplicate label" ) )
-                . q{</p></div}
+                . q{</p></div>}
                 ;
     }
     
