@@ -607,10 +607,10 @@ returns true if the EMS has subission forms attached
 sub hasSubmissionForms {
    my $self = shift;
 		   # are there ~any~ forms attached to this ems?
-   my $res = $self->getLineage(['children'],{ limit => 1,
+   my $count = $self->getDescendantCount({
 	 includeOnlyClasses => ['WebGUI::Asset::EMSSubmissionForm'],
      } );
-   return scalar(@$res);
+   return $count;
 }
 
 #-------------------------------------------------------------------
@@ -1038,12 +1038,12 @@ then call www_editSubmission on it
 sub www_editSubmission {
 	my $self             = shift;
         my $submissionId = $self->session->form->get('submissionId');
-        my $asset = $self->getLineage(['descendants'], { returnObjects => 1,
+        my $asset = $self->getLineageIterator(['descendants'], {
 		    joinClass          => "WebGUI::Asset::EMSSubmission",
 		    whereClause        => 'submissionId = ' . int($submissionId),
 		    includeOnlyClasses => ['WebGUI::Asset::EMSSubmission'],
            } );
-        return $asset->[0]->www_editSubmission;
+        return $asset->()->www_editSubmission;
 }
 
 
@@ -1389,6 +1389,7 @@ sub www_getBadgesAsJson {
     my ($db, $form) = $session->quick(qw(db form));
     my %results = ();
     $results{records} = [];
+        # TODO: Use getLineageIterator here instead
 	BADGE: foreach my $badge (@{$self->getBadges}) {
         next BADGE unless $badge->canView;
 		push(@{$results{records}}, {
@@ -2015,7 +2016,7 @@ sub www_importEvents {
 		-label   => $i18n->get('ignore first line'),
 		-name    => 'ignore_first_line',
 		-hoverHelp => $i18n->get('import hoverhelp first line'),
-		-defaultValue   => $form->param('ignore_first_line'),
+		-defaultValue   => scalar $form->param('ignore_first_line'),
 	);
 
 	# create the std & meta fields part of the form
@@ -2032,7 +2033,7 @@ sub www_importEvents {
 		name				=> 'fieldsToImport',
 		defaultValue		=> \@defaultImportableFields,
 		options				=> \%importableFields,
-		value				=> $form->get('fieldsToImport'),
+		value				=> scalar $form->get('fieldsToImport'),
 	);
 
 	$f->submit(-value=>$i18n->get('import events'));
@@ -2455,7 +2456,8 @@ Method to move an event down one position in display order
 sub www_moveEventMetaFieldDown {
 	my $self = shift;
 	return $self->session->privilege->insufficient unless ($self->canEdit);
-	$self->moveCollateralDown('EMSEventMetaField', 'fieldId', $self->session->form->get("fieldId"));
+    my $fieldId = $self->session->form->get("fieldId");
+	$self->moveCollateralDown('EMSEventMetaField', 'fieldId', $fieldId);
 	return $self->www_manageEventMetaFields;
 }
 
@@ -2470,7 +2472,8 @@ Method to move an event metdata field up one position in display order
 sub www_moveEventMetaFieldUp {
 	my $self = shift;
 	return $self->session->privilege->insufficient unless ($self->canEdit);
-	$self->moveCollateralUp('EMSEventMetaField', 'fieldId', $self->session->form->get("fieldId"));
+    my $fieldId = $self->session->form->get("fieldId");
+	$self->moveCollateralUp('EMSEventMetaField', 'fieldId', $fieldId);
 	return $self->www_manageEventMetaFields;
 }
 
