@@ -215,36 +215,106 @@ Returns the number of children this asset has. This excludes assets in the trash
 
 =head3 opts
 
-A hashref of options.  Currently only one option is supported.
+A hashref of options.  
 
 =head4 includeTrash
 
 If this value of this hash key is true, then assets in any state will be counted.  Normally,
 only those that are published or achived are counted.
 
+=head4 includeOnlyClasses
+
+Only count these classes. Arrayref of class names
+
+=head4 statusToInclude
+
+Arrayref of status to include
+
 =cut
 
 sub getChildCount {
 	my $self = shift;
-    my $opts = shift || {};
-	my $stateWhere = $opts->{includeTrash} ? '' : "asset.state='published' and";
-	my ($count) = $self->session->db->quickArray("select count(distinct asset.assetId) from asset, assetData where asset.assetId=assetData.assetId and $stateWhere parentId=? and (assetData.status in ('approved', 'archived') or assetData.tagId=?)", [$self->getId, $self->session->scratch->get('versionTag')]);
+    my $opt = shift || {};
+    $opt->{ statusToInclude } ||= [ 'approved', 'archived' ];
+
+    my $db  = $self->session->db;
+    my $sql = "select count(distinct asset.assetId) 
+                from asset, assetData 
+                where asset.assetId=assetData.assetId 
+                    and parentId=? 
+                    and (assetData.status in (" . $db->quoteAndJoin( $opt->{statusToInclude} ) . ") 
+                        or assetData.tagId=?)";
+    my @params  = ( $self->getId, $self->session->scratch->get('versionTag') );
+
+    if ( !$opt->{ includeTrash } ) {
+        $sql .= ' AND asset.state=?';
+        push @params, "published";
+    }
+    # XXX This code is duplicated in getLineageSql and getDescendantCount. Merge the three ways?
+    if ( $opt->{ includeOnlyClasses } ) {
+        my @classes;
+        if ( !ref $opt->{includeOnlyClasses} eq 'ARRAY' ) {
+            @classes = $opt->{includeOnlyClasses};
+        }
+        else {
+            @classes = @{ $opt->{includeOnlyClasses} };
+        }
+        $sql .= "AND className IN (" . join( ',', ("?") x @classes ) . ")";
+        push @params, @classes;
+    }
+	my $count = $self->session->db->quickScalar($sql, \@params);
 	return $count;
 }
 
 #-------------------------------------------------------------------
 
-=head2 getDescendantCount ( )
+=head2 getDescendantCount ( opts )
 
 Returns the number of descendants this asset has. This includes only assets that are published, and not
 in the clipboard or trash.
 
+=head3 opts
+
+=head4 includeOnlyClasses
+
+Only count these classes. Arrayref of class names
+
+=head4 statusToInclude
+
+Arrayref of status to include
+
 =cut
 
 sub getDescendantCount {
 	my $self = shift;
-	my ($count) = $self->session->db->quickArray("select count(distinct asset.assetId) from asset, assetData where asset.assetId=assetData.assetId and asset.state = 'published' and assetData.status in ('approved','archived') and asset.lineage like ?", [$self->get("lineage")."%"]);
-	$count--; # have to subtract self
+        my $opt = shift || {};
+        $opt->{ statusToInclude } ||= [ 'approved', 'archived' ];
+
+        my $db  = $self->session->db;
+
+        my $sql  = "select count(distinct asset.assetId) 
+                    from asset, assetData
+                    where asset.assetId = assetData.assetId 
+                        and asset.assetId != ?
+                        and asset.state = 'published' 
+                        and assetData.status in (" . $db->quoteAndJoin( $opt->{statusToInclude} ) . ") 
+                        and asset.lineage like ? ";
+        my @params = ( $self->getId, $self->get("lineage")."%" );
+
+        # XXX This code is duplicated in getLineageSql and getChildCount. Merge the three ways?
+        if ( $opt->{includeOnlyClasses} ) {
+            my @classes;
+            if ( !ref $opt->{includeOnlyClasses} eq 'ARRAY' ) {
+                @classes = $opt->{includeOnlyClasses};
+            }
+            else {
+                @classes = @{ $opt->{includeOnlyClasses} };
+            }
+            $sql .= "AND className IN (" . join( ',', ("?") x @classes ) . ")";
+            push @params, @classes;
+        }
+
+	my $count = $self->session->db->quickScalar($sql, \@params);
 	return $count;
 }
 
@@ -264,13 +334,15 @@ sub getFirstChild {
 		my $lineage = $assetLineage->{firstChild}{$self->getId};
 		unless ($lineage) {
 			($lineage) = $self->session->db->quickArray("select min(asset.lineage) from asset,assetData where asset.parentId=? and asset.assetId=assetData.assetId and asset.state='published'",[$self->getId]);
-			unless ($self->session->config->get("disableCache")) {
+			if ($lineage && !$self->session->config->get("disableCache")) {
 				$assetLineage->{firstChild}{$self->getId} = $lineage;
 				$self->session->stow->set("assetLineage", $assetLineage);
 			}
 		}
-		$child = WebGUI::Asset->newByLineage($self->session,$lineage);
-		$self->cacheChild(first => $child);
+        if ($lineage) {
+            $child = WebGUI::Asset->newByLineage($self->session,$lineage);
+            $self->cacheChild(first => $child);
+        }
 	}
 	return $child;
 }
@@ -344,10 +416,6 @@ An array reference containing a list of asset classes to remove from the result
 
 A boolean indicating that we should return objects rather than asset ids.
 
-=head4 returnSQL
-
-A boolean indicating that we should return the sql statement rather than asset ids.
-
 =head4 invertTree
 
 A boolean indicating whether the resulting asset tree should be returned in reverse order.
@@ -370,7 +438,8 @@ A string containing as asset class to join in. There is no real reason to use a
 
 =head4 whereClause
 
-A string containing extra where clause information for the query.
+A string containing extra WHERE clause information for the query.  The AND conjunction will be added internally, so the clause
+should not start with AND.
 
 =head4 orderByClause 
 
@@ -513,6 +582,7 @@ An integer describing how many levels of ancestry from the start point that shou
 =head4 excludeClasses
 
 An array reference containing a list of asset classes to remove from the result set. The opposite of the includOnlyClasses rule.
+Each class is internally appended with a SQL wildcard, so any subclass will also be excluded.
 
 =head4 invertTree
 
@@ -920,14 +990,21 @@ sub setRank {
 	my $parentLineage = $self->getParentLineage;
 
     my $reverse = ($newRank < $currentRank) ? 1 : 0;
-	my $siblings = $self->getLineage(["siblings"],{returnObjects=>1, invertTree=>$reverse});
 
 	my $temp = substr($self->session->id->generate(),0,6);
 	my $previous = $self->get("lineage");
 	$self->session->db->beginTransaction;
     $outputSub->('moving %s aside', $self->getTitle);
 	$self->cascadeLineage($temp);
-	foreach my $sibling (@{$siblings}) {
+	my $siblingIter = $self->getLineageIterator(["siblings"],{invertTree=>$reverse});
+        while ( 1 ) {
+            my $sibling;
+            eval { $sibling = $siblingIter->() };
+            if ( my $x = WebGUI::Error->caught('WebGUI::Error::ObjectNotFound') ) {
+                $self->session->log->error($x->full_message);
+                next;
+            }
+            last unless $sibling;
 		if (isBetween($sibling->getRank, $newRank, $currentRank)) {
             $outputSub->('moving %s', $sibling->getTitle);
 			$sibling->cascadeLineage($previous);
