@@ -65,7 +65,7 @@ A hash reference containing a list of properties to associate with the child.
 =head3 revisionDate
 
 An epoch date representing the date/time stamp that this revision was 
-created. Defaults to $self->session->datetime->time().
+created. Defaults to time().
 
 =head3 options
 
@@ -87,7 +87,7 @@ Posts) will know not to send them under certain conditions.
 sub addRevision {
     my $self             = shift;
     my $properties       = shift || {};
-    my $now              = shift     || $self->session->datetime->time();
+    my $now              = shift     || time();
     my $options          = shift;
 
     my $autoCommitId     = $self->getAutoCommitWorkflowId() unless ($options->{skipAutoCommitWorkflows});
@@ -109,7 +109,7 @@ sub addRevision {
             $workingTag = WebGUI::VersionTag->getWorking( $self->session );
         }
         else {
-            my $oldWorking = WebGUI::VersionTag->getWorking($self->session, 'noCreate');
+            $oldWorking = WebGUI::VersionTag->getWorking($self->session, 'noCreate');
             $workingTag = WebGUI::VersionTag->new( $self->session, $parentAsset->get('tagId') );
             $workingTag->setWorking();
         }
@@ -277,7 +277,8 @@ sub getRevisionCount {
 
 =head2 getRevisions ( [ status ] )
 
-Returns an array reference of the revision objects of this asset.
+Returns an array reference of the revision objects of this asset, sorted by revision date in descending
+order.  The most recent version will always be first.
 
 =head3 status
 
@@ -483,6 +484,7 @@ Sets a flag so that developers know whether to send notifications out on certain
 sub setSkipNotification {
 	my $self = shift;
 	$self->session->db->write("update assetData set skipNotification=1 where assetId=? and revisionDate=?", [$self->getId, $self->get("revisionDate")]);
+    $self->{_properties}->{skipNotification} = 1;
 }
 
 #-------------------------------------------------------------------
@@ -576,7 +578,7 @@ sub updateHistory {
     my $session = $self->session;
 	my $action = shift;
 	my $userId = shift || $session->user->userId || '3';
-	my $dateStamp =$session->datetime->time();
+	my $dateStamp =time();
 	$session->db->write("insert into assetHistory (assetId, userId, actionTaken, dateStamp, url) values (?,?,?,?,?)", [$self->getId, $userId, $action, $dateStamp, $self->get('url')]);
 }
 
