@@ -809,7 +809,9 @@ Returns whether or not a method is callable
 
 sub isCallable {
 	my $self = shift;
-	return isIn($_[0],@{$self->{callable}})
+	return 1 if isIn($_[0],@{$self->{callable}});
+        return 1 if $self->can( 'www_' . $_[0] );
+        return 0;
 }
 
 #-------------------------------------------------------------------
@@ -1064,10 +1066,13 @@ sub showMessageOnLogin {
     WebGUI::Macro::process( $self->session, \$output );
 
     # Add the link to continue
+    my $session = $self->session;
+    $session->log->warn("returnUrl: >".$self->session->form->get( 'returnUrl' )."<");
+    $session->log->warn("redirectAfterLoginUrl: >".$self->session->form->get( 'returnUrl' )."<");
     my $redirectUrl =  $self->session->form->get( 'returnUrl' )
                     || $self->session->setting->get("redirectAfterLoginUrl")
                     || $self->session->scratch->get( 'redirectAfterLogin' )
-                    || $self->session->url->getSiteURL . $self->session->url->gateway()
+                    || $self->session->url->getBackToSiteURL
                     ;
 
     $output     .= '<p><a href="' . $redirectUrl . '">' . $i18n->get( 'showMessageOnLogin return' ) 
