@@ -27,7 +27,10 @@ sub getClassSelectBox {
     );
     delete $classes{"WebGUI::Asset"}; # don't want to search for the root asset
 
-    my $className = $session->form->process("class","className") || $session->scratch->get('assetManagerSearchClassName');
+    #my $className = $session->form->process("class","className") || $session->scratch->get('assetManagerSearchClassName');
+    my $className = $session->form->get('action') ? $session->form->process('class', "className")
+                  : $session->scratch->get('assetManagerSearchPageNumber')
+                  ;
     $session->scratch->set('assetManagerSearchClassName', $className);
     return WebGUI::Form::selectBox( $session, {
         name            => "class",
@@ -145,7 +148,12 @@ sub getSearchPaginator {
         $queryString    .= ';class=' . $class;
     }
 
-    my $pageNumber  = $session->form->get('pn') || $session->scratch->get('assetManagerSearchPageNumber');
+    ##If the form was submitted, we always use page #1.  Otherwise, take the page # from the
+    ##form or from the scratch variable.
+    my $pageNumber  = $session->form->get('action') ? 1
+                    : $session->form->get('pn')     ? $session->form->get('pn') 
+                    : $session->scratch->get('assetManagerSearchPageNumber')
+                    ;
     my $p           = $s->getPaginatorResultSet( $session->url->page( $queryString ), undef, $pageNumber );
 
     $session->scratch->set('assetManagerSearchPageNumber', $pageNumber);
@@ -615,11 +623,11 @@ sub www_search {
             # The markup for a single asset
             my $row_markup  = q{<tr %s ondblclick="WebGUI.AssetManager.toggleRow( this )">}
                             . q{<td class="center"><input type="checkbox" name="assetId" value="%s" onchange="WebGUI.AssetManager.toggleHighlightForRow( this )" /></td>}
-                            . q{<td class="center">%s</td>}
-                            . q{<td>%s</td>}
-                            . q{<td><img src="%s" /> %s</td>}
-                            . q{<td class="center">%s</td>}
-                            . q{<td class="right">%s</td>}
+                            . q{<td class="center">%s</td>}    #Edit
+                            . q{<td><a href="%s">%s</a></td>}  #URL/Title as link
+                            . q{<td><img src="%s" /> %s</td>}  #Type
+                            . q{<td class="center">%s</td>}    #Revision Date
+                            . q{<td class="right">%s</td>}     #Lock
                             . q{<td class="center"><a href="%s?func=manageRevisions">%s</a></td>}
                             . q{</tr>}
                             ;
@@ -629,6 +637,7 @@ sub www_search {
                             alt
                             assetId
                             editLink 
+                            url
                             title
                             iconUrl type
                             revisionDate
