@@ -100,4 +100,23 @@ sub getName {
     return WebGUI::International->new($session, 'WebGUI')->get('codearea');
 }
 
+#-------------------------------------------------------------------
+
+=head2 toHtml
+
+Add some javascript to fix hitting the tab key.
+
+=cut
+
+sub toHtml {
+    my $self = shift;
+    my $session = $self->session;
+    $session->style->setScript(
+        $session->url->extras('yui-webgui/build/codeArea/codeArea-min.js')
+    );
+    my $id = $self->get('id');
+    return $self->SUPER::toHtml(@_)
+        . qq{<script>new YAHOO.WebGUI.CodeArea('$id').render()</script>};
+}
+
 1;
