@@ -42,6 +42,15 @@ Defaults to 'url'. But if you want to use an assetId as the first parameter, the
 #-------------------------------------------------------------------
 sub process {
     my ($session, $identifier, $type) = @_;
+    if (!$identifier) {
+        $session->errorHandler->warn('AssetProxy macro called without an asset to proxy. ' 
+        . 'The macro was called through this url: '.$session->asset->get('url'));
+        if ($session->var->isAdminOn) {
+            my $i18n = WebGUI::International->new($session, 'Macro_AssetProxy');
+            return $i18n->get('invalid url');
+        }
+        return;
+    }
     my $t = ($session->errorHandler->canShowPerformanceIndicators()) ? [Time::HiRes::gettimeofday()] : undef;
     my $asset;
     if ($type eq 'assetId') {
