@@ -196,7 +196,7 @@ sub getGroupSearchForm {
 	}
 	my $output = '<div align="center">';
 	my $i18n = WebGUI::International->new($session);
-	my $f = WebGUI::HTMLForm->new($session,1);
+	my $f = WebGUI::HTMLForm->new($session, method => 'GET', );
 	foreach my $key (keys %{$params}) {
                 $f->hidden(
                         -name=>$key,
@@ -336,13 +336,13 @@ A WebGUI::Session object
 =cut
 
 sub www_autoAddToGroup {
-    my $session = shift;
-    return $session->privilege->noAccess() if ($session->user->isVisitor);
-    my $group = WebGUI::Group->new($session,$session->form->process("groupId"));
-    if ($group && $group->autoAdd) {
-        $group->addUsers([$session->user->userId],[$session->form->process("groupId")]);
-    }
-    return "";
+	my $session = shift;
+        return $session->privilege->noAccess() if ($session->user->isVisitor);
+	my $group = WebGUI::Group->new($session,$session->form->process("groupId"));
+	if ($group && $group->autoAdd) {
+		$group->addUsers([$session->user->userId],[$session->form->process("groupId")]);
+	}
+	return "";
 }
 
 #-------------------------------------------------------------------
@@ -360,13 +360,13 @@ A WebGUI::Session object
 =cut
 
 sub www_autoDeleteFromGroup {
-    my $session = shift;
-    return $session->privilege->noAccess() if ($session->user->isVisitor);
-    my $group = WebGUI::Group->new($session,$session->form->process("groupId"));
-    if ($group && $group->autoDelete) {
-        $group->deleteUsers([$session->user->userId],[$session->form->process("groupId")]);
-    }
-    return "";
+	my $session = shift;
+        return $session->privilege->noAccess() if ($session->user->isVisitor);
+	my $group = WebGUI::Group->new($session,$session->form->process("groupId"));
+	if ($group && $group->autoDelete) {
+		$group->deleteUsers([$session->user->userId],[$session->form->process("groupId")]);
+	}
+	return "";
 }
 
 #-------------------------------------------------------------------
@@ -1012,7 +1012,7 @@ sub www_manageUsersInGroup {
 	my $session = shift;
     return $session->privilege->adminOnly() unless (canEditGroup($session,$session->form->process("gid")));
 	my $i18n = WebGUI::International->new($session);
-	my $output = WebGUI::Form::formHeader($session,)
+	my $output = WebGUI::Form::formHeader($session)
 		.WebGUI::Form::hidden($session,{
 			name=>"gid",
 			value=>$session->form->process("gid")
