@@ -528,6 +528,7 @@ sub definition {
         groupIdAdminActiveSessions
         groupIdAdminAdSpace
         groupIdAdminCache
+        groupIdAdminClipboard
         groupIdAdminCron
         groupIdAdminDatabaseLink
         groupIdAdminFilePump
@@ -542,6 +543,7 @@ sub definition {
         groupIdAdminReplacements
         groupIdAdminSpectre
         groupIdAdminStatistics
+        groupIdAdminTrash
         groupIdAdminUser
         groupIdAdminUserAdd
         groupIdAdminVersionTag
