@@ -18,8 +18,10 @@ package WebGUI::Session::Url;
 use strict;
 use URI;
 use URI::Escape;
+use Scalar::Util qw( weaken );
 use WebGUI::International;
 use WebGUI::Utility;
+use Encode;
 
 
 =head1 NAME
@@ -322,7 +324,7 @@ sub getRequestedUrl {
 	my $self = shift;
 	return undef unless ($self->session->request);
 	unless ($self->{_requestedUrl}) {
-		$self->{_requestedUrl} = $self->session->request->uri;
+		$self->{_requestedUrl} = decode_utf8($self->session->request->uri);
 		my $gateway = $self->session->config->get("gateway");
 		$self->{_requestedUrl} =~ s/^$gateway([^?]*)\??.*$/$1/;
 	}
@@ -398,10 +400,15 @@ The string to make compliant. This is usually a page title or a filename.
 =cut
 
 sub makeCompliant {
-	my $self = shift;
-	my $url = shift;
-	my $i18n = WebGUI::International->new($self->session);
-	return $i18n->makeUrlCompliant($url);
+    my $self = shift;
+    my $url = shift;
+    $url =~ s{^\s+}{};          # remove leading whitespace
+    $url =~ s{\s+$}{};          # remove trailing whitespace
+    $url =~ s{^/+}{};           # remove leading slashes
+    $url =~ s{/+$}{};           # remove trailing slashes
+    $url =~ s{[^\w/:.-]+}{-}g; # replace anything aside from word or other allowed characters with dashes
+    $url =~ tr{/-}{/-}s;        # replace multiple slashes and dashes with singles.
+    return $url;
 }
 
 #-------------------------------------------------------------------
@@ -419,7 +426,9 @@ A reference to the current session.
 sub new {
 	my $class = shift;
 	my $session = shift;
-	bless {_session=>$session}, $class;
+	my $self = bless {_session=>$session}, $class;
+        weaken( $self->{_session} );
+        return $self;
 }
 
 #-------------------------------------------------------------------
@@ -521,16 +530,14 @@ The string to urlize.
 =cut
 
 sub urlize {
-    my $self = shift;
-    my ($value);
-    $value = lc(shift);		#lower cases whole string
+    my $self  = shift;
+    my $value = lc(shift);		#lower cases whole string
     $value = $self->makeCompliant($value);
 
     # remove /./ or /../
     $value =~ s{(^|/)(?:\.\.?/)*}{$1}g;
 
     # remove trailing slashes
-    $value =~ s/\/$//;
     return $value;
 }
 
