@@ -64,47 +64,50 @@ sub handler {
     my ($request, $server, $config) = @_;
     $request->push_handlers(PerlResponseHandler => sub {
         my $session = $request->pnotes('wgSession');
-        unless (defined $session) {
-            $session = WebGUI::Session->open($server->dir_config('WebguiRoot'), $config->getFilename, $request, $server);
-        }
-        WEBGUI_FATAL: foreach my $handler (@{$config->get("contentHandlers")}) {
-            my $output = eval { WebGUI::Pluggable::run($handler, "handler", [ $session ] )};
-            if ( my $e = WebGUI::Error->caught ) {
-                $session->errorHandler->error($e->package.":".$e->line." - ".$e->error);
-                $session->errorHandler->debug($e->package.":".$e->line." - ".$e->trace);
+        WEBGUI_FATAL: {
+            unless (defined $session) {
+                $session = WebGUI::Session->open($server->dir_config('WebguiRoot'), $config->getFilename, $request, $server);
+                return Apache2::Const::OK if ! defined $session;
             }
-            elsif ( $@ ) {
-                $session->errorHandler->error( $@ );
-            }
-            else {
-                if ($output eq "chunked") {
-                    if ($session->errorHandler->canShowDebug()) {
-                        $session->output->print($session->errorHandler->showDebug(),1);
-                    }
-                    last;
+            foreach my $handler (@{$config->get("contentHandlers")}) {
+                my $output = eval { WebGUI::Pluggable::run($handler, "handler", [ $session ] )};
+                if ( my $e = WebGUI::Error->caught ) {
+                    $session->errorHandler->error($e->package.":".$e->line." - ".$e->error);
+                    $session->errorHandler->debug($e->package.":".$e->line." - ".$e->trace);
                 }
-                if ($output eq "empty") {
-                    if ($session->errorHandler->canShowDebug()) {
-                        $session->output->print($session->errorHandler->showDebug(),1);
-                    }
-                    last;
+                elsif ( $@ ) {
+                    $session->errorHandler->error( $@ );
                 }
-                elsif (defined $output && $output ne "") {
-                    $session->http->sendHeader;
-                    $session->output->print($output);
-                    if ($session->errorHandler->canShowDebug()) {
-                        $session->output->print($session->errorHandler->showDebug(),1);
+                else {
+                    if ($output eq "chunked") {
+                        if ($session->errorHandler->canShowDebug()) {
+                            $session->output->print($session->errorHandler->showDebug(),1);
+                        }
+                        last;
+                    }
+                    if ($output eq "empty") {
+                        if ($session->errorHandler->canShowDebug()) {
+                            $session->output->print($session->errorHandler->showDebug(),1);
+                        }
+                        last;
+                    }
+                    elsif (defined $output && $output ne "") {
+                        $session->http->sendHeader;
+                        $session->output->print($output);
+                        if ($session->errorHandler->canShowDebug()) {
+                            $session->output->print($session->errorHandler->showDebug(),1);
+                        }
+                        last;
+                    }
+                    # Keep processing for success codes
+                    elsif ($session->http->getStatus < 200 || $session->http->getStatus > 299) {
+                        $session->http->sendHeader;
+                        last;
                     }
-                    last;
-                }
-                # Keep processing for success codes
-                elsif ($session->http->getStatus < 200 || $session->http->getStatus > 299) {
-                    $session->http->sendHeader;
-                    last;
                 }
             }
         }
-        $session->close;
+        $session->close if defined $session;
         return Apache2::Const::OK;
     });
     $request->push_handlers(PerlMapToStorageHandler => sub { return Apache2::Const::OK });
