@@ -676,14 +676,9 @@ sub start {
 	# hand off the workflow to spectre
 	$log->info('Could not complete workflow instance '.$self->getId.' in realtime, handing off to Spectre.');
 	my $spectre = WebGUI::Workflow::Spectre->new($self->session);
-	$spectre->notify("workflow/addInstance", {cookieName=>$self->session->config->getCookieName, gateway=>$self->session->config->get("gateway"), sitename=>$self->session->config->get("sitename")->[0], instanceId=>$self->getId, priority=>$self->{_data}{priority}});
+	my $success = $spectre->notify("workflow/addInstance", {cookieName=>$self->session->config->getCookieName, gateway=>$self->session->config->get("gateway"), sitename=>$self->session->config->get("sitename")->[0], instanceId=>$self->getId, priority=>$self->{_data}{priority}});
 
-    my $spectreTest = WebGUI::Operation::Spectre::spectreTest($self->session);
-    if($spectreTest ne "success"){
-        return WebGUI::International->new($self->session, "Macro_SpectreCheck")->get($spectreTest);
-    }
-
-    return undef;
+	return $success ? undef : 'Could not connect to spectre';
 }
 
 1;
