@@ -5,6 +5,22 @@ our $I18N = {
     'lastUpdated' => '1242720820',
     'message' => 'Carrousel'
   },
+  'carousel autoPlay description' => {
+    'lastUpdated' => '1302247834',
+    'message' => 'Moet deze carrousel automatisch door alle items heenbladeren?'
+  },
+  'carousel autoPlay label' => {
+    'lastUpdated' => '1302247900',
+    'message' => 'Automatisch afspelen'
+  },
+  'carousel autoPlayInterval description' => {
+    'lastUpdated' => '1302247921',
+    'message' => 'Tijd in seconden tussen de verschillende items'
+  },
+  'carousel autoPlayInterval label' => {
+    'lastUpdated' => '1302247938',
+    'message' => 'Interval automatisch afspelen'
+  },
   'carousel slideHeight description' => {
     'lastUpdated' => '1280491551',
     'message' => 'De hoogte in pixels. De Carousel zal zich niet aanpassen aan inhoud met verschillende afmetingen. Door deze hoogte in te stellen, zal de pagina goed gerenderd worden. Als de standaard hoogte, 0, ingesteld blijft staan, wordt de hoogte die van het eerste element.'
@@ -33,6 +49,10 @@ our $I18N = {
     'lastUpdated' => '1242720906',
     'message' => 'Carrousel sjabloon'
   },
+  'delete' => {
+    'lastUpdated' => '1295896369',
+    'message' => 'Verwijderen'
+  },
   'id description' => {
     'lastUpdated' => '1242720940',
     'message' => 'Geef een uniek ID aan voor dit carrousel item'
