@@ -320,6 +320,11 @@ our $I18N = {
 		context => q|To remove an item from the clipboard, and put it on the current page.|
 	},
 
+    'Copy Assets' => {
+        message => q|Copy Assets|,
+        lastUpdated => 1273518396,
+    },
+
 	'Paste Assets' => {
 		message => q|Paste Assets|,
 		lastUpdated => 1245342798,
@@ -1266,6 +1271,12 @@ Couldn't open %-s because %-s <br />
         context     => q{Error message in Asset.pm},
     },
 
+    'clear package flag' => {
+        message     => q{Clear package flag},
+        lastUpdate  => 1275419384,
+        context     => q{Package import option in admin console},
+    },
+
     'need a userId parameter' => {
         message     => q{need a userId parameter},
         lastUpdated => 0,
