@@ -14,8 +14,8 @@ our $I18N = {
     'message' => 'von'
   },
   'Edited_on' => {
-    'lastUpdated' => '1179837807',
-    'message' => 'Bearbeitet ??'
+    'lastUpdated' => '1277325454',
+    'message' => 'Bearbeitet am'
   },
   'Skip notification' => {
     'lastUpdated' => '1269421925',
@@ -190,8 +190,8 @@ our $I18N = {
     'message' => 'Bedingung, die wahr ist, falls der Benuzter einen neuen Post hinzufügt. Gegenteil vom Bearbeiten eines schon existierenden Posts.'
   },
   'isNewThread' => {
-    'lastUpdated' => '1179834361',
-    'message' => 'Bedingung, die wahr ist, falls der Benutzer einen neuen Post hinzufügt.'
+    'lastUpdated' => '1278344415',
+    'message' => 'Bedingung, die wahr ist, falls der Benutzer einen neuen Thread hinzufügt.'
   },
   'isPackage' => {
     'lastUpdated' => '1179834378',
@@ -202,8 +202,12 @@ our $I18N = {
     'message' => 'Bedingung, die anzeigt, ob dieser Post ein Inhaltsprototyp ist.'
   },
   'isReply' => {
-    'lastUpdated' => '1179834424',
-    'message' => 'Bedingung, die wahr ist, falls der Benuzter auf einen existierenden Post antwortet.'
+    'lastUpdated' => '1278344369',
+    'message' => 'Bedingung, die wahr ist, falls der Benutzer auf einen existierenden Post antwortet.'
+  },
+  'isSubscribedToCs' => {
+    'lastUpdated' => '1278344547',
+    'message' => 'Ein boolscher Wert, der wahr ist, falls der aktuelle Benutzer das CS mit diesem Beitrag abonniert hat.'
   },
   'isThread' => {
     'lastUpdated' => '1179834473',
@@ -262,8 +266,8 @@ our $I18N = {
     'message' => 'URL zum Post, der die Benachrichtigung ausgelöst hat.'
   },
   'notify.subscription.message' => {
-    'lastUpdated' => '1215073098',
-    'message' => '<p>Internationalisierte Nachricht über eine neue Nachricht zu einem vom Benutzer abbonierten Thema.</p>'
+    'lastUpdated' => '1277325503',
+    'message' => 'Internationalisierte Nachricht über eine neue Nachricht zu einem vom Benutzer abonnierten Thema.'
   },
   'ownerUserId' => {
     'lastUpdated' => '1179835012',
@@ -278,12 +282,12 @@ our $I18N = {
     'message' => 'Post Asset Template Variablen'
   },
   'post received' => {
-    'lastUpdated' => '1179835168',
-    'message' => 'Ihr Post wurde entgegengenommen und wird zurzeit verarbeitet, damit er zur Site hinzugefügt werden kann. Bitte haben Sie ein wenig Geduld.'
+    'lastUpdated' => '1286874142',
+    'message' => 'Ihre Nachricht wurde entgegengenommen und wird zurzeit verarbeitet, damit diese zur Site hinzugefügt werden kann. Bitte haben Sie ein wenig Geduld.'
   },
   'post template variables title' => {
-    'lastUpdated' => '1170408865',
-    'message' => 'Post Template Variablen<br />'
+    'lastUpdated' => '1277325573',
+    'message' => 'Post Template Variablen'
   },
   'preview.content' => {
     'lastUpdated' => '1179835102',
