@@ -457,6 +457,10 @@ our $I18N = {
     'lastUpdated' => '1241298388',
     'message' => 'Angabe, ob der Benutzer bereits eine Versandadresse angegeben hat. Diese Versandadresse ist immer notwendig um die Steuer errechnen zu können.'
   },
+  'hasSku' => {
+    'lastUpdated' => '1303289636',
+    'message' => 'Ein boolscher Wert, der wahr ist, wenn das Asset, auf das sich dieser Artikel bezieht, noch in WebGUI enthalten ist. Ist diese Variable \'false\', dann sollte <strong>viewItemURL</strong> nicht genutzt werden'
+  },
   'import tax' => {
     'lastUpdated' => '1240756543',
     'message' => 'Importsteuer'
@@ -581,6 +585,10 @@ our $I18N = {
     'lastUpdated' => '1241158116',
     'message' => 'Name Versandadresse für dieses Item'
   },
+  'item sku deleted' => {
+    'lastUpdated' => '1303289660',
+    'message' => 'Das Asset zu diesem Artikel kann nicht instantiiert werden.'
+  },
   'item taxAmount help' => {
     'lastUpdated' => '1279222235',
     'message' => 'Steuer für diesen Artikel. Diese Variable steht nur zur Verfügung, wenn der aktuelle Benutzer nicht \'Besucher\' ist.'
