@@ -5,6 +5,22 @@ our $I18N = {
     'lastUpdated' => '1252512946',
     'message' => 'Carrusel'
   },
+  'carousel autoPlay description' => {
+    'lastUpdated' => '1302868491',
+    'message' => 'Indica si este Carrusel iniciará de manera automática la secuencia de presentación de los items que contiene.'
+  },
+  'carousel autoPlay label' => {
+    'lastUpdated' => '1302868500',
+    'message' => 'Reproducción Automática'
+  },
+  'carousel autoPlayInterval description' => {
+    'lastUpdated' => '1302868531',
+    'message' => 'Intervalo de tiempo entre el despliegue de dos elementos del Carrusel.'
+  },
+  'carousel autoPlayInterval label' => {
+    'lastUpdated' => '1302868554',
+    'message' => 'Intervalo entre Items'
+  },
   'carousel slideHeight description' => {
     'lastUpdated' => '1280335493',
     'message' => 'Altura en pixels. El Carrusel no cambia sus dimensiones cuando el contenido a mostrar tiene alturas variables. Establecer este parámetro facilita la presentación adecuada. El valor por omisión es cero, que establece la altura del Carrusel con el mismo valor que la altura del primer elemento a mostrar.'
@@ -33,6 +49,10 @@ our $I18N = {
     'lastUpdated' => '1252513157',
     'message' => 'Plantilla para el Carrusel'
   },
+  'delete' => {
+    'lastUpdated' => '1302868562',
+    'message' => 'Eliminar'
+  },
   'id description' => {
     'lastUpdated' => '1252513181',
     'message' => 'Indique el ID único para este ítem en el Carrusel.'
