@@ -1,14 +1,30 @@
 package WebGUI::i18n::Spanish::Shop;
 use utf8;
 our $I18N = {
+  'Add new address' => {
+    'lastUpdated' => '1276809145',
+    'message' => 'Agregar dirección'
+  },
   'Backordered' => {
     'lastUpdated' => '1253917361',
     'message' => 'Pendientes'
   },
+  'Billing Address' => {
+    'lastUpdated' => '1276809154',
+    'message' => 'Dirección de Cobro'
+  },
   'Cancelled' => {
     'lastUpdated' => '1215809342',
     'message' => 'Cancelado'
   },
+  'Choose a payment gateway and update the cart to checkout' => {
+    'lastUpdated' => '1276809179',
+    'message' => 'Seleccionar un método de pago y actualizar el Carrito para completar la compra'
+  },
+  'Choose a payment method' => {
+    'lastUpdated' => '1276809192',
+    'message' => 'Seleccione el método de pago.'
+  },
   'Choose a shipping method' => {
     'lastUpdated' => '1255726232',
     'message' => 'Seleccione el método de envío'
@@ -45,6 +61,14 @@ our $I18N = {
     'lastUpdated' => '1221672533',
     'message' => 'Enviado'
   },
+  'Shipping Address' => {
+    'lastUpdated' => '1276809201',
+    'message' => 'Dirección de Envío'
+  },
+  'Special shipping' => {
+    'lastUpdated' => '1276809210',
+    'message' => 'Envío Especial'
+  },
   'Status' => {
     'lastUpdated' => '1257425060',
     'message' => 'Estado'
@@ -53,6 +77,10 @@ our $I18N = {
     'lastUpdated' => '1257425068',
     'message' => 'Exitoso'
   },
+  'Update %s' => {
+    'lastUpdated' => '1276809223',
+    'message' => 'Actualizar dirección: %s'
+  },
   'add a new address' => {
     'lastUpdated' => '1215809416',
     'message' => 'Adicionar una nueva direcci&oacute;n'
@@ -149,6 +177,46 @@ our $I18N = {
     'lastUpdated' => '1215812523',
     'message' => 'Disponible'
   },
+  'billing address1' => {
+    'lastUpdated' => '1276809284',
+    'message' => 'Ingrese la dirección de cobro'
+  },
+  'billing city' => {
+    'lastUpdated' => '1276809299',
+    'message' => 'Ingrese la ciudad para la dirección de cobro.'
+  },
+  'billing code' => {
+    'lastUpdated' => '1276809313',
+    'message' => 'Ingrese el código postal para la dirección de cobro'
+  },
+  'billing country' => {
+    'lastUpdated' => '1276809325',
+    'message' => 'Ingrese el país para la dirección de cobro.'
+  },
+  'billing firstName' => {
+    'lastUpdated' => '1276809338',
+    'message' => 'Ingrese el nombre del destinatario en la dirección de cobro.'
+  },
+  'billing label' => {
+    'lastUpdated' => '1276809351',
+    'message' => 'Ingrese una etiqueta para la dirección de cobro.'
+  },
+  'billing lastName' => {
+    'lastUpdated' => '1276809366',
+    'message' => 'Ingrese el apellido del destinatario para la dirección de cobro.'
+  },
+  'billing phoneNumber' => {
+    'lastUpdated' => '1276809396',
+    'message' => 'Ingrese el número de teléfono de la dirección de cobro.'
+  },
+  'billing state' => {
+    'lastUpdated' => '1276809407',
+    'message' => 'Ingrese el estado o provincia de la dirección de cobro.'
+  },
+  'billingAddressChooser help' => {
+    'lastUpdated' => '1280866091',
+    'message' => 'Una lista de selección a partir de la cual seleccionar la dirección de cobranza por omisión.'
+  },
   'biweekly' => {
     'lastUpdated' => '1215812534',
     'message' => 'Dos semanas'
@@ -269,6 +337,10 @@ our $I18N = {
     'lastUpdated' => '1221674064',
     'message' => 'Cup&oacute;n'
   },
+  'current credit message' => {
+    'lastUpdated' => '1276809422',
+    'message' => '%s tiene un crédito de %s.'
+  },
   'date' => {
     'lastUpdated' => '1221674077',
     'message' => 'Fecha'
@@ -325,6 +397,10 @@ our $I18N = {
     'lastUpdated' => '1226520087',
     'message' => 'Correo Electr&oacute;nico'
   },
+  'emailField help' => {
+    'lastUpdated' => '1280866117',
+    'message' => 'Un campo para contener la dirección de correo electrónico asociada a esta dirección.'
+  },
   'empty cart' => {
     'lastUpdated' => '1221674416',
     'message' => 'No hay items actualmente en tu carrito.'
@@ -429,6 +505,10 @@ our $I18N = {
     'lastUpdated' => '1222105414',
     'message' => 'El assetId para este item.'
   },
+  'item extendedPricePlusTax help' => {
+    'lastUpdated' => '1280866178',
+    'message' => 'La el precio del item más el impuesto, multiplicado por la cantidad de items como este en el carrito. Esta variable solamente tendrá valor cuando el usuario actual no es el Invitado.'
+  },
   'item lastUpdated' => {
     'lastUpdated' => '1222105678',
     'message' => 'La fecha en que se actualiz&oacute; por &uacute;ltima vez la transacci&oacute;n de este item.'
@@ -445,6 +525,10 @@ our $I18N = {
     'lastUpdated' => '1222105835',
     'message' => 'El precio sin formatear de este SKU.'
   },
+  'item pricePlusTax help' => {
+    'lastUpdated' => '1280866223',
+    'message' => 'El precio del item más el monto del impuesto. Esta variable tendrá valor solamente cuando el usuario actual no sea el usuario Invitado.'
+  },
   'item quantity' => {
     'lastUpdated' => '1222105856',
     'message' => 'La cantidad del SKU que fue comprado.'
@@ -493,6 +577,14 @@ our $I18N = {
     'lastUpdated' => '1222111090',
     'message' => 'El nombre asignado a la direcci&oacute;n de env&iacute;o de este item.'
   },
+  'item taxAmount help' => {
+    'lastUpdated' => '1280866251',
+    'message' => 'El monto del impuesto para este item. Esta variable solamente tendrá valor si el usuario actual no es el usuario Invitado.'
+  },
+  'item taxRate help' => {
+    'lastUpdated' => '1280866276',
+    'message' => 'La tasa de impuesto para este item. Esta variable solamente tendrá valor si el usuario actual no es el usuario Invitado.'
+  },
   'item transactionId' => {
     'lastUpdated' => '1222110126',
     'message' => 'El ID de la transacci&oacute;n que pertenece este item.'
@@ -505,6 +597,10 @@ our $I18N = {
     'lastUpdated' => '1222110179',
     'message' => 'El ID del vendedor de este item.'
   },
+  'itemAddressChooser help' => {
+    'lastUpdated' => '1280866323',
+    'message' => 'Una lista de selección de la cual escoger la dirección de envío para un item individual en el carrito, permitiendo envío separado por item.'
+  },
   'itemId' => {
     'lastUpdated' => '1222110251',
     'message' => 'El identificador &uacute;nico para este item entre todos los items en todas las transacciones.'
@@ -537,6 +633,26 @@ our $I18N = {
     'lastUpdated' => '1222111641',
     'message' => 'Debes estar logueado para pagar. Para loguearte has click <a href="%s">aqu&iacute;</a>'
   },
+  'loginFormButton help' => {
+    'lastUpdated' => '1280866362',
+    'message' => 'El botón para enviar el formulario de autenticación. Esta variable solamente tendrá valor si el usuario actual no es el usuario Invitado.'
+  },
+  'loginFormFooter help' => {
+    'lastUpdated' => '1280866400',
+    'message' => 'Fragmento de HTML para terminar el formulario de autenticación. Esta variable solamente tendrá valor si el usuario actual no es el usuario Invitado.'
+  },
+  'loginFormHeader help' => {
+    'lastUpdated' => '1280866430',
+    'message' => 'Fragmento de HTML para comenzar el formulario de autenticación. Esta variable tendrá valor solamente si el usuario actual no es el usuario Invitado.'
+  },
+  'loginFormPassword help' => {
+    'lastUpdated' => '1280866484',
+    'message' => 'El campo de texto en el cual el usuario introduce su clave. Esta variable tendrá valor solamente si el usuario actual no es el usuario Invitado.'
+  },
+  'loginFormUsername help' => {
+    'lastUpdated' => '1280866516',
+    'message' => 'El campo de texto en el cual el usuario introduce su nombre. Esta variable tendrá valor solamente si el usuario actual no es el usuario Invitado.'
+  },
   'manage' => {
     'lastUpdated' => '1221857909',
     'message' => 'Administrar'
@@ -549,6 +665,10 @@ our $I18N = {
     'lastUpdated' => '1222111715',
     'message' => 'Esta plantila muestra informaci&oacute;n parcial sobre las transacciones al usuario.'
   },
+  'message help' => {
+    'lastUpdated' => '1280866541',
+    'message' => 'Si el carrito de compras está vacío, presentar este mensaje al usuario.'
+  },
   'minicart template' => {
     'lastUpdated' => '1222111745',
     'message' => 'Plantilla MiniCart'
@@ -557,6 +677,10 @@ our $I18N = {
     'lastUpdated' => '1222111856',
     'message' => 'Las siguientes variables estan disponibles en la plantilla de la macro MiniCart.'
   },
+  'minimumCartAmount help' => {
+    'lastUpdated' => '1280866575',
+    'message' => 'El monto mínimo en el carrito de compras según la configuración, con dos lugares decimales.'
+  },
   'mixed items warning' => {
     'lastUpdated' => '1222185905',
     'message' => '<div id="result_box" dir="ltr">No es posible pagar con los items recurrentes y no recurrentes en su carrito. Puede tener ya sea un item recurrente, o como muchos items no recurrentes como desee en su carrito de compra en el tiempo. Si usted necesita comprar ambos, a continuaci&oacute;n, por favor comprarlos por transacciones separado las transacciones.</div>'
@@ -593,6 +717,14 @@ our $I18N = {
     'lastUpdated' => '1222455678',
     'message' => 'El nombre de la persona de esta direcci&oacute;n.'
   },
+  'no billing address' => {
+    'lastUpdated' => '1276809508',
+    'message' => 'Ingrese una dirección de cobro, o indique alguna existente.'
+  },
+  'no shipping address' => {
+    'lastUpdated' => '1276809523',
+    'message' => 'Ingrese una dirección de envío, o indique alguna existente.'
+  },
   'not applicable' => {
     'lastUpdated' => '1222455694',
     'message' => 'N/A'
@@ -697,6 +829,10 @@ our $I18N = {
     'lastUpdated' => '1222459749',
     'message' => 'El departamento para la direcci&oacute;n de pago.'
   },
+  'paymentOptions help' => {
+    'lastUpdated' => '1280866613',
+    'message' => 'Una lista de selección conteniendo todos los métodos de pago para esta orden.'
+  },
   'per item shipping' => {
     'lastUpdated' => '1222459820',
     'message' => 'Por item enviado'
@@ -769,10 +905,18 @@ our $I18N = {
     'lastUpdated' => '1222698227',
     'message' => 'Reembolso'
   },
+  'registerLink help' => {
+    'lastUpdated' => '1280866655',
+    'message' => 'El enlace para que el usuario registre una cuenta en este sitio, cuando no tengan una. Esta variable tendrá valor solamente si el usuario actual es el usuario Invitado.'
+  },
   'remove button' => {
     'lastUpdated' => '1222698237',
     'message' => 'Borrar'
   },
+  'removeBox help' => {
+    'lastUpdated' => '1280867141',
+    'message' => 'Un checkbox que permite retirar este item del carrito.'
+  },
   'removeButton help' => {
     'lastUpdated' => '1222698266',
     'message' => 'Al hacer click en este bot&oacute;n borrar&aacute; ek item del carrito.'
@@ -789,6 +933,10 @@ our $I18N = {
     'lastUpdated' => '1259455935',
     'message' => 'Indique el Grupo de usuarios que deben recibir notificaciones cuando ocurran transacciones.'
   },
+  'sameShippingAsBilling help' => {
+    'lastUpdated' => '1280867177',
+    'message' => 'Un checkbox para indicar al carrito de compras que el usuario emplea la misma dirección de envío como dirección de cobranza.'
+  },
   'saveButton help' => {
     'lastUpdated' => '1222979583',
     'message' => 'El bot&oacute;n por defecto para guardar el formulario.'
@@ -821,6 +969,10 @@ our $I18N = {
     'lastUpdated' => '1222979562',
     'message' => 'Hace lo mismo queel bot&oacute;n Elegir direcci&oacute;n de env&iacute;o'
   },
+  'shippableItemsInCart' => {
+    'lastUpdated' => '1276809546',
+    'message' => 'Un condicional que indica si al menos un item en el carrito requiere envío.'
+  },
   'shipping' => {
     'lastUpdated' => '1222911598',
     'message' => 'Envio'
@@ -829,17 +981,53 @@ our $I18N = {
     'lastUpdated' => '1222911711',
     'message' => 'Direcci&oacute;n de Env&iacute;o'
   },
+  'shipping address1' => {
+    'lastUpdated' => '1276809563',
+    'message' => 'Indique la dirección de envío.'
+  },
   'shipping amount' => {
     'lastUpdated' => '1222979413',
     'message' => 'Valor de Env&iacute;o'
   },
+  'shipping city' => {
+    'lastUpdated' => '1276809579',
+    'message' => 'Indique la ciudad de la dirección de envío.'
+  },
+  'shipping code' => {
+    'lastUpdated' => '1276809621',
+    'message' => 'Indique el código postal para la dirección de envío.'
+  },
+  'shipping country' => {
+    'lastUpdated' => '1276809632',
+    'message' => 'Indique el país para la dirección de envío.'
+  },
+  'shipping firstName' => {
+    'lastUpdated' => '1276809668',
+    'message' => 'Indique el nombre del destinatario en la dirección de envío.'
+  },
+  'shipping label' => {
+    'lastUpdated' => '1276809686',
+    'message' => 'Indique la etiqueta para la dirección de envío.'
+  },
+  'shipping lastName' => {
+    'lastUpdated' => '1276809700',
+    'message' => 'Indique el apellido del destinatario en la dirección de envío.'
+  },
   'shipping method' => {
-    'lastUpdated' => '1222277092',
-    'message' => 'M&eacute;todo de Compra'
+    'lastUpdated' => '1276809715',
+    'message' => 'Método de Envío'
   },
   'shipping methods' => {
-    'lastUpdated' => '1222979430',
-    'message' => 'M&eacute;todos de Env&iacute;o'
+    'lastUpdated' => '1276809730',
+    'message' => 'Métodos de Envío'
+  },
+  'shipping phoneNumber' => {
+    'lastUpdated' => '1276809742',
+    'message' => 'Indique el teléfono de contacto para la dirección de envío.'
+  },
+  'shipping state' => {
+    'lastUpdated' => '1276809754',
+    'message' => 'Indique el estado/provincia para la dirección de envío.'
   },
   'shippingAddress help' => {
     'lastUpdated' => '1222979464',
@@ -857,6 +1045,10 @@ our $I18N = {
     'lastUpdated' => '1222911779',
     'message' => 'La tercera l&iacute;nea en una multil&iacute;nea de direcciones de env&iacute;o.'
   },
+  'shippingAddressChooser help' => {
+    'lastUpdated' => '1280866786',
+    'message' => 'Una lista de selección para escoger la dirección de despacho por defecto para todos los items del carrito. También contiene acciones para editar o agregar direcciones.'
+  },
   'shippingAddressCity' => {
     'lastUpdated' => '1222911793',
     'message' => 'La ciudad de la direcci&oacute;n de env&iacute;o.'
@@ -1025,6 +1217,10 @@ our $I18N = {
     'lastUpdated' => '1221788819',
     'message' => '<div id="result_box" dir="ltr">Al hacer clic en este bot&oacute;n se aplicar&aacute;n los cambios realizados en el carro y recalcular todos los precios.</div>'
   },
+  'use same shipping as billing' => {
+    'lastUpdated' => '1276809777',
+    'message' => 'Usar dirección de envío como dirección de cobro.'
+  },
   'use this address' => {
     'lastUpdated' => '1215811268',
     'message' => 'Usar Esta Direcci&oacute;n'
@@ -1037,6 +1233,10 @@ our $I18N = {
     'lastUpdated' => '1215811157',
     'message' => 'El userId del usuario que realiza esta transacci&oacute;n.'
   },
+  'userIsVisitor help' => {
+    'lastUpdated' => '1280866744',
+    'message' => 'Un condicional que indica si el usuario actual es el Invitado.'
+  },
   'username' => {
     'lastUpdated' => '1215811068',
     'message' => 'Usuario'
